@@ -418,7 +418,12 @@ class LibspecManager(object):
 
         self._main_thread = threading.current_thread()
 
-        assert observer
+        if observer is None:
+            from robocorp_ls_core.watchdog_wrapper import create_observer
+
+            log.info("No observer passed to LibspecManager (creating dummy observer).")
+
+            observer = create_observer("dummy", [])
         self._fs_observer = observer
 
         self._file_changes_notifier = watchdog_wrapper.create_notifier(
