@@ -10,7 +10,15 @@ OPTION_ROBOT_VARIABLES = "robot.variables"
 
 OPTION_ROBOT_LINT_ROBOCOP_ENABLED = "robot.lint.robocop.enabled"
 
+OPTION_ROBOT_COMPLETION_KEYWORDS_FORMAT = "robot.completions.keywords.format"
+OPTION_ROBOT_COMPLETION_KEYWORDS_FORMAT_FIRST_UPPER = "First upper"
+OPTION_ROBOT_COMPLETION_KEYWORDS_FORMAT_TITLE = "Title Case"
+OPTION_ROBOT_COMPLETION_KEYWORDS_FORMAT_ALL_LOWER = "all lower"
+OPTION_ROBOT_COMPLETION_KEYWORDS_FORMAT_ALL_UPPER = "ALL UPPER"
+
+
 OPTION_ROBOT_PYTHONPATH = "robot.pythonpath"
+
 OPTION_ROBOT_WORKSPACE_SYMBOLS_ONLY_FOR_OPEN_DOCS = (
     "robot.workspaceSymbolsOnlyForOpenDocs"
 )
@@ -35,5 +43,6 @@ ALL_ROBOT_OPTIONS = frozenset(
         OPTION_ROBOT_PYTHONPATH,
         OPTION_ROBOT_COMPLETION_SECTION_HEADERS_FORM,
         OPTION_ROBOT_WORKSPACE_SYMBOLS_ONLY_FOR_OPEN_DOCS,
+        OPTION_ROBOT_COMPLETION_KEYWORDS_FORMAT,
     )
 )
