@@ -25,6 +25,7 @@ if typing.TYPE_CHECKING:
     from robocorp_ls_core.lsp import HoverResponseTypedDict
     from robocorp_ls_core.lsp import TextDocumentTypedDict
     from robocorp_ls_core.lsp import ResponseTypedDict
+    from robocorp_ls_core.lsp import CodeLensTypedDict
 
 # Hack so that we don't break the runtime on versions prior to Python 3.8.
 if sys.version_info[:2] < (3, 8):
@@ -128,7 +129,10 @@ class IEndPoint(Protocol):
 
 
 class CommunicationDropped(object):
-    pass
+    def __str__(self):
+        return "CommunicationDropped"
+
+    __repr__ = __str__
 
 
 class IMessageMatcher(Generic[T], Protocol):
@@ -221,7 +225,7 @@ class IRobotFrameworkApiClient(ILanguageServerClientBase, Protocol):
     ):
         pass
 
-    def get_version(self):
+    def get_version(self) -> str:
         pass
 
     def lint(self, doc_uri: str) -> "ResponseTypedDict":
@@ -396,6 +400,9 @@ class ILanguageServerClient(ILanguageServerClientBase, Protocol):
     def request_code_lens(self, uri: str):
         pass
 
+    def request_resolve_code_lens(self, code_lens: "CodeLensTypedDict"):
+        pass
+
     def request_document_symbol(self, uri: str):
         pass
 
@@ -644,6 +651,14 @@ class IMonitor(Protocol):
         """
 
 
+class ActionResultDict(TypedDict):
+    success: bool
+    message: Optional[
+        str
+    ]  # if success == False, this can be some message to show to the user
+    result: Any
+
+
 class ActionResult(Generic[T]):
 
     success: bool
@@ -659,18 +674,10 @@ class ActionResult(Generic[T]):
         self.message = message
         self.result = result
 
-    def as_dict(self):
+    def as_dict(self) -> ActionResultDict:
         return {"success": self.success, "message": self.message, "result": self.result}
 
     def __str__(self):
         return f"ActionResult(success={self.success!r}, message={self.message!r}, result={self.result!r})"
 
     __repr__ = __str__
-
-
-class ActionResultDict(TypedDict):
-    success: bool
-    message: Optional[
-        str
-    ]  # if success == False, this can be some message to show to the user
-    result: Any
